==> mars-src-1.0.1.tar.gz: mars-src-1.0.1/core/src/common/kernel_internal_types.h <==
/*
 * Copyright 2008 Sony Corporation of America
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this Library and associated documentation files (the
 * "Library"), to deal in the Library without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Library, and to
 * permit persons to whom the Library is furnished to do so, subject to
 * the following conditions:
 *
 *  The above copyright notice and this permission notice shall be
 *  included in all copies or substantial portions of the Library.
 *
 *  If you modify the Library, you may copy and distribute your modified
 *  version of the Library in object code or as an executable provided
 *  that you also do one of the following:
 *
 *   Accompany the modified version of the Library with the complete
 *   corresponding machine-readable source code for the modified version
 *   of the Library; or,
 *
 *   Accompany the modified version of the Library with a written offer
 *   for a complete machine-readable copy of the corresponding source
 *   code of the modified version of the Library.
 *
 *
 * THE LIBRARY IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * LIBRARY OR THE USE OR OTHER DEALINGS IN THE LIBRARY.
 */

#ifndef MARS_KERNEL_INTERNAL_TYPES_H
#define MARS_KERNEL_INTERNAL_TYPES_H

#include <stdint.h>

#define MARS_KERNEL_PARAMS_ALIGN	128

/* mars kernel parameters */
struct mars_kernel_params {
	uint32_t id;
	uint64_t mars_context_ea;
	uint64_t workload_queue_ea;
} __attribute__((aligned(MARS_KERNEL_PARAMS_ALIGN)));

#endif

==> mars-src-1.1.0.tar.gz: mars-src-1.1.0/core/src/common/kernel_internal_types.h <==
/*
 * Copyright 2008 Sony Corporation of America
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this Library and associated documentation files (the
 * "Library"), to deal in the Library without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Library, and to
 * permit persons to whom the Library is furnished to do so, subject to
 * the following conditions:
 *
 *  The above copyright notice and this permission notice shall be
 *  included in all copies or substantial portions of the Library.
 *
 *  If you modify the Library, you may copy and distribute your modified
 *  version of the Library in object code or as an executable provided
 *  that you also do one of the following:
 *
 *   Accompany the modified version of the Library with the complete
 *   corresponding machine-readable source code for the modified version
 *   of the Library; or,
 *
 *   Accompany the modified version of the Library with a written offer
 *   for a complete machine-readable copy of the corresponding source
 *   code of the modified version of the Library.
 *
 *
 * THE LIBRARY IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * LIBRARY OR THE USE OR OTHER DEALINGS IN THE LIBRARY.
 */

#ifndef MARS_KERNEL_INTERNAL_TYPES_H
#define MARS_KERNEL_INTERNAL_TYPES_H

#include <stdint.h>

#define MARS_KERNEL_STATUS_BUSY			0x0
#define MARS_KERNEL_STATUS_IDLE			0x1
#define MARS_KERNEL_STATUS_EXIT			0x2
#define MARS_KERNEL_TICKS_FLAG_SYNC_BEGIN	0x1
#define MARS_KERNEL_TICKS_FLAG_SYNC_END		0x2
#define MARS_KERNEL_PARAMS_ALIGN		128
#define MARS_KERNEL_PARAMS_SIZE			128

/* mars kernel syscalls */
struct mars_kernel_syscalls {
	void				   (*module_exit)(uint8_t state);
	uint32_t			   (*get_ticks)(void);
	uint64_t			   (*get_mars_context_ea)(void);
	uint32_t			   (*get_kernel_id)(void);
	uint16_t			   (*get_workload_id)(void);
	struct mars_workload_context *     (*get_workload)(void);
	struct mars_workload_queue_header *(*get_workload_queue_header)(void);
	struct mars_workload_queue_block * (*get_workload_queue_block)(void);
};

/* mars kernel ticks */
struct mars_kernel_ticks {
	uint32_t flag;
	uint32_t offset;
};

/* mars kernel parameters */
struct mars_kernel_params {
	uint32_t kernel_id;
	uint32_t pad1;
	uint64_t mars_context_ea;
	uint64_t workload_queue_ea;
	struct mars_kernel_ticks kernel_ticks;
	uint8_t pad2[MARS_KERNEL_PARAMS_SIZE - 32];
} __attribute__((aligned(MARS_KERNEL_PARAMS_ALIGN)));

/* mars module entry */
void mars_module_entry(struct mars_kernel_syscalls *syscalls);

#endif
